@@ -195,6 +195,7 @@ wnck_window_get_type (void)
         sizeof (WnckWindow),
         0,              /* n_preallocs */
         (GInstanceInitFunc) wnck_window_init,
+        NULL            /* value_table */
       };
 
       object_type = g_type_register_static (G_TYPE_OBJECT,
@@ -480,6 +481,14 @@ wnck_window_get_application  (WnckWindow *window)
   return window->priv->app;
 }
 
+WnckWindow*
+wnck_window_get_transient (WnckWindow *window)
+{
+  g_return_val_if_fail (WNCK_IS_WINDOW (window), None);
+
+  return wnck_window_get (window->priv->transient_for);
+}
+
 gulong
 wnck_window_get_group_leader (WnckWindow *window)
 {
@@ -598,6 +607,63 @@ wnck_window_get_window_type (WnckWindow *window)
   return window->priv->wintype;
 }
 
+/**
+ * wnck_window_set_window_type:
+ * @window: a #WnckWindow
+ * @wintype: the #WnckWindowType type hint
+ * 
+ * Sets the semantic type of the window.
+ * 
+ **/
+void
+wnck_window_set_window_type (WnckWindow *window, WnckWindowType wintype)
+{
+  Atom atom;
+
+  g_return_if_fail (WNCK_IS_WINDOW (window));
+
+  switch (wintype) {
+  case WNCK_WINDOW_NORMAL:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_NORMAL");
+    break;
+  case WNCK_WINDOW_DESKTOP:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_DESKTOP");
+    break;
+  case WNCK_WINDOW_DOCK:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_DOCK");
+    break;
+  case WNCK_WINDOW_DIALOG:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_DIALOG");
+    break;
+  case WNCK_WINDOW_MODAL_DIALOG:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_MODAL_DIALOG");
+    break;
+  case WNCK_WINDOW_TOOLBAR:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_TOOLBAR");
+    break;
+  case WNCK_WINDOW_MENU:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_MENU");
+    break;
+  case WNCK_WINDOW_UTILITY:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_UTILITY");
+    break;
+  case WNCK_WINDOW_SPLASHSCREEN:
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_SPLASHSCREEN");
+    break;
+  default:
+    return;
+  }
+  _wnck_error_trap_push ();
+
+  XChangeProperty (gdk_display,
+                   window->priv->xwindow, 
+                   _wnck_atom_get ("_NET_WM_WINDOW_TYPE"),
+		   XA_ATOM, 32, PropModeReplace,
+		   (guchar *)&atom, 1);
+
+  _wnck_error_trap_pop ();
+}
+
 /**
  * wnck_window_is_minimized:
  * @window: a #WnckWindow
@@ -1092,6 +1158,8 @@ wnck_window_unpin (WnckWindow *window)
 /**
  * wnck_window_activate:
  * @window: a #WnckWindow
+ * @timestamp: the X server timestamp of the user interaction event that
+ *             caused this call to occur
  *
  * Ask the window manager to make @window the active window.  The
  * window manager may choose to raise @window along with focusing it.
@@ -1184,6 +1252,8 @@ find_last_transient_for (GList *windows,
 /**
  * wnck_window_activate_transient:
  * @window: a #WnckWindow
+ * @timestamp: the X server timestamp of the user interaction event that
+ *             caused this call to occur
  *
  * If @window has transients, activates the most likely transient
  * instead of the window itself. Otherwise activates @window.
@@ -1229,10 +1299,13 @@ wnck_window_activate_transient (WnckWindow *window,
 }
 
 /**
- * wnck_window_transient_is_active:
+ * wnck_window_transient_is_most_recently_activated:
  * @window: a #WnckWindow
  *
- * Return whether one of the transients of @window has focus.  This
+ * Return whether one of the transients of @window is the most
+ * recently activated window.  See
+ * wnck_window_is_most_recently_activated() for a more complete
+ * description of what is meant by most recently activated.  This
  * function is needed because clicking on the tasklist once will
  * activate a transient instead of the window itself
  * (wnck_window_activate_transient), and clicking again should
@@ -1242,7 +1315,7 @@ wnck_window_activate_transient (WnckWindow *window,
  * 
  **/
 gboolean
-wnck_window_transient_is_active (WnckWindow *window)
+wnck_window_transient_is_most_recently_activated (WnckWindow *window)
 {
   GList *windows;
   WnckWindow *transient;
@@ -1259,7 +1332,7 @@ wnck_window_transient_is_active (WnckWindow *window)
       if (transient == window)
         return FALSE;
 
-      if (wnck_window_is_active (transient))
+      if (wnck_window_is_most_recently_activated (transient))
         return TRUE;
     }
 
@@ -1703,6 +1776,7 @@ update_state (WnckWindow *window)
       window->priv->skip_taskbar = FALSE;
       window->priv->skip_pager = FALSE;
       window->priv->net_wm_state_hidden = FALSE;
+      window->priv->is_fullscreen = FALSE;
       window->priv->demands_attention = FALSE;
       
       atoms = NULL;
